.. _source:


.. raw:: html

     <br>

.. title:: Source


.. raw:: html

    <center>


source
######

.. raw:: html

     </center>


**GENOCIDE**

.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    president.bus	bus
    president.command   commands
    president.error	errors
    president.event	events
    president.json	decoder/encoder
    president.locks	locks module
    president.modules   plugins
    president.object	a clean namespace
    president.parser	parsing
    president.reactor   reacting
    president.repeater  repeating 
    president.thread    threading
    president.utils     utilities


.. raw:: html

     <br>


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    president.modules.cmd	list of commands
    president.modules.dbg 	debug module
    president.modules.err	occured errors
    president.modules.flt	list of bots
    president.modules.irc	internet relay chat
    president.modules.log	log text
    president.modules.mdl	genocide model
    president.modules.req	request
    president.modules.rss	rich site syndicate
    president.modules.sts	status of bots
    president.modules.tdo	todo list
    president.modules.udp	udp to irc relay
    president.modules.wsd 	wisdom
